Welcome to Sina Tools Documentation!
====================================

.. image:: _static/download.png

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Contents:

   installation
   readme
   authors
   DataDownload

.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Modules:

   api





